diff --git a/.gitlab-ci.yml b/.gitlab-ci.yml
index 6311e654974104495e8f77e6fa53cb1e9dee9282..b8dafdd4127606f173d7d04afbc827d9e0a6ae53 100644
--- a/.gitlab-ci.yml
+++ b/.gitlab-ci.yml
@@ -3,8 +3,8 @@ include:
     file: /ci/general.yml
   - project: "AlekSIS/official/AlekSIS"
     file: /ci/prepare/lock.yml
-  - project: "AlekSIS/official/AlekSIS"
-    file: /ci/test/test.yml
+  #  - project: "AlekSIS/official/AlekSIS"
+  #    file: /ci/test/test.yml
   - project: "AlekSIS/official/AlekSIS"
     file: /ci/test/lint.yml
   - project: "AlekSIS/official/AlekSIS"
diff --git a/aleksis/apps/chronos/admin.py b/aleksis/apps/chronos/admin.py
index f75e9f611e0eb73f456c780bed9f961b67d260f6..9da4770d092663c4baa2c5a9e770677305ea0121 100644
--- a/aleksis/apps/chronos/admin.py
+++ b/aleksis/apps/chronos/admin.py
@@ -23,7 +23,6 @@ from .models import (
     SupervisionArea,
     SupervisionSubstitution,
     TimePeriod,
-    TimetableWidget,
     ValidityRange,
 )
 from .util.format import format_date_period, format_m2m
@@ -209,13 +208,6 @@ class TimePeriodAdmin(admin.ModelAdmin):
 admin.site.register(TimePeriod, TimePeriodAdmin)
 
 
-class TimetableWidgetAdmin(admin.ModelAdmin):
-    list_display = ("title", "active")
-
-
-admin.site.register(TimetableWidget, TimetableWidgetAdmin)
-
-
 class ValidityRangeAdmin(admin.ModelAdmin):
     list_display = ("__str__", "date_start", "date_end")
     list_display_links = ("__str__", "date_start", "date_end")
diff --git a/aleksis/apps/chronos/filters.py b/aleksis/apps/chronos/filters.py
deleted file mode 100644
index 5e231ef98ed73c3102288a09d8acabb7a39d0972..0000000000000000000000000000000000000000
--- a/aleksis/apps/chronos/filters.py
+++ /dev/null
@@ -1,178 +0,0 @@
-from collections.abc import Sequence
-
-from django.db.models import Count, Q
-from django.forms import RadioSelect
-from django.utils.translation import gettext as _
-
-from django_filters import BooleanFilter, FilterSet, ModelMultipleChoiceFilter
-from django_select2.forms import ModelSelect2MultipleWidget
-from material import Layout, Row
-
-from aleksis.core.models import Group, Person, Room, SchoolTerm
-
-from .models import Break, Subject, SupervisionArea, TimePeriod
-
-
-class MultipleModelMultipleChoiceFilter(ModelMultipleChoiceFilter):
-    """Filter for filtering multiple fields with one input.
-
-    >>> multiple_filter = MultipleModelMultipleChoiceFilter(["room", "substitution_room"])
-    """
-
-    def filter(self, qs, value):  # noqa
-        if not value:
-            return qs
-
-        if self.is_noop(qs, value):
-            return qs
-
-        q = Q()
-        for v in set(value):
-            if v == self.null_value:
-                v = None
-            for field in self.lookup_fields:
-                q = q | Q(**{field: v})
-
-            qs = self.get_method(qs)(q)
-
-        return qs.distinct() if self.distinct else qs
-
-    def __init__(self, lookup_fields: Sequence[str], *args, **kwargs):
-        self.lookup_fields = lookup_fields
-        super().__init__(self, *args, **kwargs)
-
-
-class LessonPeriodFilter(FilterSet):
-    period = ModelMultipleChoiceFilter(queryset=TimePeriod.objects.all())
-    lesson__groups = ModelMultipleChoiceFilter(
-        queryset=Group.objects.all(),
-        widget=ModelSelect2MultipleWidget(
-            attrs={"data-minimum-input-length": 0, "class": "browser-default"},
-            search_fields=[
-                "name__icontains",
-                "short_name__icontains",
-            ],
-        ),
-    )
-    room = MultipleModelMultipleChoiceFilter(
-        ["room", "current_substitution__room"],
-        queryset=Room.objects.all(),
-        label=_("Room"),
-        widget=ModelSelect2MultipleWidget(
-            attrs={"data-minimum-input-length": 0, "class": "browser-default"},
-            search_fields=[
-                "name__icontains",
-                "short_name__icontains",
-            ],
-        ),
-    )
-    lesson__teachers = MultipleModelMultipleChoiceFilter(
-        ["lesson__teachers", "current_substitution__teachers"],
-        queryset=Person.objects.none(),
-        label=_("Teachers"),
-        widget=ModelSelect2MultipleWidget(
-            attrs={"data-minimum-input-length": 0, "class": "browser-default"},
-            search_fields=[
-                "first_name__icontains",
-                "last_name__icontains",
-                "short_name__icontains",
-            ],
-        ),
-    )
-    lesson__subject = MultipleModelMultipleChoiceFilter(
-        ["lesson__subject", "current_substitution__subject"],
-        queryset=Subject.objects.all(),
-        label=_("Subject"),
-        widget=ModelSelect2MultipleWidget(
-            attrs={"data-minimum-input-length": 0, "class": "browser-default"},
-            search_fields=[
-                "name__icontains",
-                "short_name__icontains",
-            ],
-        ),
-    )
-    substituted = BooleanFilter(
-        field_name="current_substitution",
-        label=_("Substitution status"),
-        lookup_expr="isnull",
-        exclude=True,
-        widget=RadioSelect(
-            choices=[
-                ("", _("All lessons")),
-                (True, _("Substituted")),
-                (False, _("Not substituted")),
-            ]
-        ),
-    )
-
-    def __init__(self, *args, **kwargs):
-        weekday = kwargs.pop("weekday")
-        super().__init__(*args, **kwargs)
-        self.filters["period"].queryset = TimePeriod.objects.filter(weekday=weekday)
-        self.filters["lesson__teachers"].queryset = (
-            Person.objects.annotate(
-                lessons_count=Count(
-                    "lessons_as_teacher",
-                    filter=Q(lessons_as_teacher__validity__school_term=SchoolTerm.current)
-                    if SchoolTerm.current
-                    else Q(),
-                )
-            )
-            .filter(lessons_count__gt=0)
-            .order_by("short_name", "last_name")
-        )
-        self.form.layout = Layout(
-            Row("period", "lesson__groups", "room"),
-            Row("lesson__teachers", "lesson__subject", "substituted"),
-        )
-
-
-class SupervisionFilter(FilterSet):
-    break_item = ModelMultipleChoiceFilter(queryset=Break.objects.all())
-    area = ModelMultipleChoiceFilter(queryset=SupervisionArea.objects.all())
-    teacher = MultipleModelMultipleChoiceFilter(
-        ["teacher", "current_substitution__teacher"],
-        queryset=Person.objects.none(),
-        label=_("Teacher"),
-        widget=ModelSelect2MultipleWidget(
-            attrs={"data-minimum-input-length": 0, "class": "browser-default"},
-            search_fields=[
-                "first_name__icontains",
-                "last_name__icontains",
-                "short_name__icontains",
-            ],
-        ),
-    )
-    substituted = BooleanFilter(
-        field_name="current_substitution",
-        label=_("Substitution status"),
-        lookup_expr="isnull",
-        exclude=True,
-        widget=RadioSelect(
-            choices=[
-                ("", _("All supervisions")),
-                (True, _("Substituted")),
-                (False, _("Not substituted")),
-            ]
-        ),
-    )
-
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.filters["break_item"].queryset = Break.objects.filter(supervisions__in=self.queryset)
-        self.filters["teacher"].queryset = (
-            Person.objects.annotate(
-                lessons_count=Count(
-                    "lessons_as_teacher",
-                    filter=Q(lessons_as_teacher__validity__school_term=SchoolTerm.current)
-                    if SchoolTerm.current
-                    else Q(),
-                )
-            )
-            .filter(lessons_count__gt=0)
-            .order_by("short_name", "last_name")
-        )
-        self.form.layout = Layout(
-            Row("break_item", "area"),
-            Row("teacher", "substituted"),
-        )
diff --git a/aleksis/apps/chronos/forms.py b/aleksis/apps/chronos/forms.py
deleted file mode 100644
index 58664a45ecae7792e20b086450388aeecc0b0e24..0000000000000000000000000000000000000000
--- a/aleksis/apps/chronos/forms.py
+++ /dev/null
@@ -1,61 +0,0 @@
-from django import forms
-
-from django_select2.forms import ModelSelect2MultipleWidget, ModelSelect2Widget
-from material import Layout
-
-from .models import AutomaticPlan, LessonSubstitution, SupervisionSubstitution
-from .util.chronos_helpers import get_teachers
-
-
-class LessonSubstitutionForm(forms.ModelForm):
-    """Form to manage substitutions."""
-
-    class Meta:
-        model = LessonSubstitution
-        fields = ["subject", "teachers", "room", "cancelled", "comment"]
-        widgets = {
-            "teachers": ModelSelect2MultipleWidget(
-                search_fields=[
-                    "first_name__icontains",
-                    "last_name__icontains",
-                    "short_name__icontains",
-                ],
-                attrs={"data-minimum-input-length": 0, "class": "browser-default"},
-            ),
-        }
-
-    def __init__(self, request, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.request = request
-        self.fields["teachers"].queryset = get_teachers(request.user)
-
-
-class SupervisionSubstitutionForm(forms.ModelForm):
-    """Form to manage supervisions substitutions."""
-
-    class Meta:
-        model = SupervisionSubstitution
-        fields = ["teacher"]
-        widgets = {
-            "teacher": ModelSelect2Widget(
-                search_fields=[
-                    "first_name__icontains",
-                    "last_name__icontains",
-                    "short_name__icontains",
-                ],
-                attrs={"data-minimum-input-length": 0, "class": "browser-default"},
-            ),
-        }
-
-    def __init__(self, request, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.request = request
-        self.fields["teacher"].queryset = get_teachers(request.user)
-
-
-class AutomaticPlanForm(forms.ModelForm):
-    layout = Layout("slug", "name", "number_of_days", "show_header_box")
-
-    class Meta:
-        model = AutomaticPlan
-        fields = ["slug", "name", "number_of_days", "show_header_box"]
diff --git a/aleksis/apps/chronos/frontend/components/AmendLesson.vue b/aleksis/apps/chronos/frontend/components/AmendLesson.vue
index 1d6ac1fadd0570fdf85aeb429bebc0ed3a210e6c..2d9f8b4c9d2798ba0afcedeb4711debbfa1ae0fc 100644
--- a/aleksis/apps/chronos/frontend/components/AmendLesson.vue
+++ b/aleksis/apps/chronos/frontend/components/AmendLesson.vue
@@ -77,6 +77,7 @@
       :gql-delete-mutation="gqlDeleteMutation"
       v-model="deleteEvent"
       :items="[selectedEvent.meta]"
+      :get-name-of-item="getLessonDeleteText"
       @save="updateOnSave()"
     >
       <template #title>
@@ -173,6 +174,12 @@ export default {
       this.$emit("refreshCalendar");
       this.model = false;
     },
+    getLessonDeleteText(item) {
+      return `${this.selectedEvent.name} · ${this.$d(
+        this.selectedEvent.start,
+        "shortDateTime",
+      )} – ${this.$d(this.selectedEvent.end, "shortTime")}`;
+    },
   },
   computed: {
     initPatchData() {
diff --git a/aleksis/apps/chronos/frontend/components/LessonEventSubject.vue b/aleksis/apps/chronos/frontend/components/LessonEventSubject.vue
index 9a739936f497ad6f63b1d2780d244ab3b5b74092..7bbb83712b0cd556ca4e7d7fb07d43e59a8766c3 100644
--- a/aleksis/apps/chronos/frontend/components/LessonEventSubject.vue
+++ b/aleksis/apps/chronos/frontend/components/LessonEventSubject.vue
@@ -36,7 +36,7 @@ export default {
       {{ event.meta.amends.subject[attr] }}
     </span>
     <span v-else>
-      {{ event[attr] }}
+      {{ event["name"] }}
     </span>
   </span>
 </template>
diff --git a/aleksis/apps/chronos/frontend/components/SelectTimetable.vue b/aleksis/apps/chronos/frontend/components/SelectTimetable.vue
index 6e1931e71f89a0fc608ce6714866c5174592947d..76543ac322a63cff1af8e948bbab5f81dd088aa1 100644
--- a/aleksis/apps/chronos/frontend/components/SelectTimetable.vue
+++ b/aleksis/apps/chronos/frontend/components/SelectTimetable.vue
@@ -106,6 +106,11 @@ export default {
           </v-list-item-group>
         </v-list>
       </template>
+      <template #loading>
+        <v-skeleton-loader
+          type="list-item-avatar,list-item-avatar,list-item-avatar"
+        />
+      </template>
     </v-data-iterator>
   </div>
 </template>
diff --git a/aleksis/apps/chronos/frontend/components/calendar_feeds/details/LessonDetails.vue b/aleksis/apps/chronos/frontend/components/calendar_feeds/details/LessonDetails.vue
index 0c9311450f0c7d8c3e922743f1403382da1148ce..627dd2fe2e8395da29d8d6c4162e29b99b2f1d1e 100644
--- a/aleksis/apps/chronos/frontend/components/calendar_feeds/details/LessonDetails.vue
+++ b/aleksis/apps/chronos/frontend/components/calendar_feeds/details/LessonDetails.vue
@@ -5,13 +5,17 @@
     without-location
   >
     <template #title>
-      <div
-        :style="{
-          color: currentSubject ? currentSubject.colour_fg || 'white' : 'white',
-        }"
-      >
-        <lesson-event-subject :event="selectedEvent" />
-      </div>
+      <slot name="title">
+        <div
+          :style="{
+            color: currentSubject
+              ? currentSubject.colour_fg || 'white'
+              : 'white',
+          }"
+        >
+          <lesson-event-subject :event="selectedEvent" />
+        </div>
+      </slot>
     </template>
     <template #badge>
       <cancelled-calendar-status-chip
diff --git a/aleksis/apps/chronos/frontend/components/calendar_feeds/details/SupervisionDetails.vue b/aleksis/apps/chronos/frontend/components/calendar_feeds/details/SupervisionDetails.vue
index 7d6455a054fd8d7a46433ea5ad4693e4c40ff43e..2aa6f026bc3745d71dcd0dd6a8f823b4a8f1af42 100644
--- a/aleksis/apps/chronos/frontend/components/calendar_feeds/details/SupervisionDetails.vue
+++ b/aleksis/apps/chronos/frontend/components/calendar_feeds/details/SupervisionDetails.vue
@@ -1,109 +1,20 @@
 <template>
-  <base-calendar-feed-details
-    v-bind="$props"
-    :color="currentSubject ? currentSubject.colour_bg : null"
-    without-location
-  >
+  <lesson-details v-bind="$attrs" v-on="$listeners">
     <template #title>
-      <div
-        :style="{
-          color: currentSubject ? currentSubject.colour_fg || 'white' : 'white',
-        }"
-      >
-        <lesson-event-subject :event="selectedEvent" />
-      </div>
+      <v-icon class="mr-1">mdi-coffee</v-icon>
+      {{ $t("chronos.supervisions.title") }}
     </template>
-    <template #badge>
-      <cancelled-calendar-status-chip
-        v-if="selectedEvent.meta.cancelled"
-        class="ml-4"
-      />
-      <calendar-status-chip
-        color="warning"
-        icon="mdi-clipboard-alert-outline"
-        v-else-if="selectedEvent.meta.amended"
-        class="ml-4"
-      >
-        {{ $t("chronos.event.current_changes") }}
-      </calendar-status-chip>
-    </template>
-    <template #description>
-      <v-divider inset />
-      <v-list-item>
-        <v-list-item-icon>
-          <v-icon color="primary">mdi-human-male-board </v-icon>
-        </v-list-item-icon>
-        <v-list-item-content>
-          <v-list-item-title>
-            <span v-if="teachers.length === 0" class="body-2 text--secondary">{{
-              $t("chronos.event.no_teacher")
-            }}</span>
-            <lesson-related-object-chip
-              v-for="teacher in teachers"
-              :status="teacher.status"
-              :key="teacher.id"
-              new-icon="mdi-account-plus-outline"
-              >{{ teacher.full_name }}</lesson-related-object-chip
-            >
-          </v-list-item-title>
-        </v-list-item-content>
-      </v-list-item>
-      <v-list-item>
-        <v-list-item-icon>
-          <v-icon color="primary">mdi-door </v-icon>
-        </v-list-item-icon>
-        <v-list-item-content>
-          <v-list-item-title>
-            <span v-if="rooms.length === 0" class="body-2 text--secondary">{{
-              $t("chronos.event.no_room")
-            }}</span>
-            <lesson-related-object-chip
-              v-for="room in rooms"
-              :status="room.status"
-              :key="room.id"
-              new-icon="mdi-door-open"
-              >{{ room.name }}</lesson-related-object-chip
-            >
-          </v-list-item-title>
-        </v-list-item-content>
-      </v-list-item>
-      <v-divider inset />
-      <v-list-item v-if="selectedEvent.meta.comment">
-        <v-list-item-content>
-          <v-list-item-title>
-            <v-alert
-              dense
-              outlined
-              type="warning"
-              icon="mdi-information-outline"
-            >
-              {{ selectedEvent.meta.comment }}
-            </v-alert>
-          </v-list-item-title>
-        </v-list-item-content>
-      </v-list-item>
-    </template>
-  </base-calendar-feed-details>
+  </lesson-details>
 </template>
 
 <script>
-import calendarFeedDetailsMixin from "aleksis.core/mixins/calendarFeedDetails.js";
-import BaseCalendarFeedDetails from "aleksis.core/components/calendar/BaseCalendarFeedDetails.vue";
-import CalendarStatusChip from "aleksis.core/components/calendar/CalendarStatusChip.vue";
-import CancelledCalendarStatusChip from "aleksis.core/components/calendar/CancelledCalendarStatusChip.vue";
+import LessonDetails from "./LessonDetails.vue";
 
-import LessonRelatedObjectChip from "../../LessonRelatedObjectChip.vue";
-import lessonEvent from "../mixins/lessonEvent";
-import LessonEventSubject from "../../LessonEventSubject.vue";
 export default {
-  name: "LessonDetails",
+  name: "SupervisionDetails",
+  extends: [LessonDetails],
   components: {
-    LessonEventSubject,
-    LessonRelatedObjectChip,
-    BaseCalendarFeedDetails,
-    CalendarStatusChip,
-    CancelledCalendarStatusChip,
+    LessonDetails,
   },
-  mixins: [calendarFeedDetailsMixin, lessonEvent],
 };
 </script>
diff --git a/aleksis/apps/chronos/frontend/components/calendar_feeds/event_bar/LessonEventBar.vue b/aleksis/apps/chronos/frontend/components/calendar_feeds/event_bar/LessonEventBar.vue
index 1f0eb6527d0859ead2edb1cf120ec5ef84b5c6c3..b63154d6e8017cb4cb6cf07a9c1fb4475d499994 100644
--- a/aleksis/apps/chronos/frontend/components/calendar_feeds/event_bar/LessonEventBar.vue
+++ b/aleksis/apps/chronos/frontend/components/calendar_feeds/event_bar/LessonEventBar.vue
@@ -11,9 +11,10 @@
         class="d-flex justify-start"
         :class="{
           'px-1': true,
-          'orange-border':
+          'current-changes':
             selectedEvent.meta.amended && !selectedEvent.meta.cancelled,
-          'red-border': selectedEvent.meta.cancelled,
+          cancelled: selectedEvent.meta.cancelled,
+          'text-decoration-line-through': selectedEvent.meta.cancelled,
         }"
         :style="{
           color: currentSubject ? currentSubject.colour_fg || 'white' : 'white',
@@ -31,6 +32,8 @@
           class="d-flex justify-center align-center flex-grow-1 text-truncate"
         >
           <div class="d-flex justify-center align-center flex-wrap text">
+            <slot name="additionalElements"></slot>
+
             <lesson-event-link-iterator
               v-if="!selectedEvent.meta.is_member"
               :items="selectedEvent.meta.groups"
@@ -46,6 +49,7 @@
             />
 
             <lesson-event-subject
+              v-if="withSubject"
               :event="selectedEvent"
               attr="short_name"
               class="font-weight-medium mr-1"
@@ -83,16 +87,23 @@ export default {
       return this.event;
     },
   },
+  props: {
+    withSubject: {
+      type: Boolean,
+      default: true,
+      required: false,
+    },
+  },
   mixins: [calendarFeedEventBarMixin, lessonEvent],
 };
 </script>
 
 <style scoped>
-.orange-border {
+.current-changes {
   border: 3px orange solid;
 }
 
-.red-border {
+.cancelled {
   border: 3px red solid;
 }
 
diff --git a/aleksis/apps/chronos/frontend/components/calendar_feeds/event_bar/SupervisionEventBar.vue b/aleksis/apps/chronos/frontend/components/calendar_feeds/event_bar/SupervisionEventBar.vue
new file mode 100644
index 0000000000000000000000000000000000000000..59894990ee7d74358dc43a5c9719fb7d543c81a0
--- /dev/null
+++ b/aleksis/apps/chronos/frontend/components/calendar_feeds/event_bar/SupervisionEventBar.vue
@@ -0,0 +1,19 @@
+<template>
+  <lesson-event-bar :with-subject="false" v-bind="$attrs" v-on="$listeners">
+    <template #additionalElements>
+      <v-icon size="12" color="white" class="mr-1">mdi-coffee</v-icon>
+    </template>
+  </lesson-event-bar>
+</template>
+
+<script>
+import LessonEventBar from "./LessonEventBar.vue";
+
+export default {
+  name: "SupervisionEventBar",
+  components: {
+    LessonEventBar,
+  },
+  extends: [LessonEventBar],
+};
+</script>
diff --git a/aleksis/apps/chronos/frontend/index.js b/aleksis/apps/chronos/frontend/index.js
index df94b20515a109e1ab6b09fa5f64d44785e63e84..1b2e15d28716e0be6487c3f565f324412b4997b7 100644
--- a/aleksis/apps/chronos/frontend/index.js
+++ b/aleksis/apps/chronos/frontend/index.js
@@ -25,6 +25,7 @@ export default {
         titleKey: "chronos.timetable.menu_title",
         icon: "mdi-grid",
         permission: "chronos.view_timetable_overview_rule",
+        fullWidth: true,
       },
     },
     {
@@ -33,6 +34,7 @@ export default {
       name: "chronos.timetableWithId",
       meta: {
         permission: "chronos.view_timetable_overview_rule",
+        fullWidth: true,
       },
     },
     {
diff --git a/aleksis/apps/chronos/frontend/messages/de.json b/aleksis/apps/chronos/frontend/messages/de.json
index cd6011a3e2ef31838f55d3619bea9c75c0649bcc..23bfc5e4114761e98846ee2dbaffc12519071028 100644
--- a/aleksis/apps/chronos/frontend/messages/de.json
+++ b/aleksis/apps/chronos/frontend/messages/de.json
@@ -1,37 +1,32 @@
 {
   "chronos": {
-    "menu_title": "Stundenpläne",
-    "timetable": {
-      "menu_title": "Stundenpläne",
-      "menu_title_all": "Alle Stundenpläne",
-      "menu_title_my": "Mein Stundenplan",
-      "no_timetable_selected": {
-        "title": "Kein Stundenplan ausgewählt",
-        "description": "Wählen Sie auf der linken Seite einen Stundenplan aus, um ihn hier anzuzeigen"
-      },
-      "search": "Stundenpläne suchen",
-      "prev": "Vorheriger Stundenplan",
-      "next": "Nächster Stundenplan",
-      "select": "Stundenplan auswählen",
-      "types": {
-        "groups": "Gruppen",
+    "event": {
+      "amend": {
+        "cancelled": "Fällt aus",
+        "comment": "Kommentar",
+        "delete_button": "Zurücksetzen",
+        "delete_dialog": "Sind Sie sicher, dass Sie diese Vertretung löschen wollen?",
+        "delete_success": "Die Vertretung wurde erfolgreich gelöscht.",
+        "edit_button": "Ändern",
+        "rooms": "Räume",
+        "subject": "Fach",
         "teachers": "Lehrkräfte",
-        "rooms": "Räume"
-      }
+        "title": "Stunde ändern"
+      },
+      "current_changes": "Aktuelle Änderungen",
+      "no_room": "Kein Raum",
+      "no_teacher": "Keine Lehrkraft"
     },
     "lessons": {
       "menu_title_daily": "Tagesstunden"
     },
+    "menu_title": "Stundenpläne",
     "substitutions": {
       "menu_title": "Vertretungen"
     },
     "supervisions": {
-      "menu_title_daily": "Aufsichten"
-    },
-    "event": {
-      "no_teacher": "Keine Lehrkraft",
-      "no_room": "Kein Raum",
-      "current_changes": "Aktuelle Änderungen"
+      "menu_title_daily": "Aufsichten",
+      "title": "Aufsicht"
     },
     "amend_lesson": {
       "overview": {
@@ -45,6 +40,24 @@
           "decancel": "Stunde nicht ausfallen lassen"
         }
       }
+    },
+    "timetable": {
+      "menu_title": "Stundenpläne",
+      "menu_title_all": "Alle Stundenpläne",
+      "menu_title_my": "Mein Stundenplan",
+      "next": "Nächster Stundenplan",
+      "no_timetable_selected": {
+        "description": "Wählen Sie auf der linken Seite einen Stundenplan aus, um ihn hier anzuzeigen",
+        "title": "Kein Stundenplan ausgewählt"
+      },
+      "prev": "Vorheriger Stundenplan",
+      "search": "Stundenpläne suchen",
+      "select": "Stundenplan auswählen",
+      "types": {
+        "groups": "Gruppen",
+        "rooms": "Räume",
+        "teachers": "Lehrkräfte"
+      }
     }
   }
 }
diff --git a/aleksis/apps/chronos/frontend/messages/en.json b/aleksis/apps/chronos/frontend/messages/en.json
index 0b5c7fa800371dec773fb9293693d83872bcc26e..e849590286d8eaeb44dfed4f02226e1c595c45f7 100644
--- a/aleksis/apps/chronos/frontend/messages/en.json
+++ b/aleksis/apps/chronos/frontend/messages/en.json
@@ -26,6 +26,7 @@
       "menu_title": "Substitutions"
     },
     "supervisions": {
+      "title": "Supervision",
       "menu_title_daily": "Daily supervisions"
     },
     "event": {
@@ -35,7 +36,7 @@
       "amend": {
         "edit_button": "Change",
         "delete_button": "Reset",
-        "delete_dialog": " Are you sure you want to delete this substitution?",
+        "delete_dialog": "Are you sure you want to delete this substitution?",
         "delete_success": "The substitution was deleted successfully.",
         "title": "Change lesson",
         "subject": "Subject",
diff --git a/aleksis/apps/chronos/frontend/messages/ru.json b/aleksis/apps/chronos/frontend/messages/ru.json
index 6bb3faf3b14ca3db2fc364b318b0e26173f0cd35..fb663b2ba0a8d4ea0cdb26857b19f8e7856a1816 100644
--- a/aleksis/apps/chronos/frontend/messages/ru.json
+++ b/aleksis/apps/chronos/frontend/messages/ru.json
@@ -1,18 +1,28 @@
 {
   "chronos": {
-    "timetable": {
-      "menu_title_all": "Все расписания",
-      "menu_title_my": "Моё расписание"
+    "event": {
+      "amend": {
+        "cancelled": "Отменено",
+        "rooms": "Комнаты"
+      }
     },
-    "supervisions": {
-      "menu_title_daily": "Ежедневные наблюдения"
-    },
-    "menu_title": "Расписания",
     "lessons": {
       "menu_title_daily": "Ежедневные уроки"
     },
+    "menu_title": "Расписания",
     "substitutions": {
       "menu_title": "Замены"
+    },
+    "supervisions": {
+      "menu_title_daily": "Ежедневные наблюдения"
+    },
+    "timetable": {
+      "menu_title_all": "Все расписания",
+      "menu_title_my": "Моё расписание",
+      "types": {
+        "groups": "Группы",
+        "rooms": "Комнаты"
+      }
     }
   }
 }
diff --git a/aleksis/apps/chronos/frontend/messages/uk.json b/aleksis/apps/chronos/frontend/messages/uk.json
index 6f1d391299725bcf831c427bb91c7fbac65bac89..09d0c8ac28b91229ad842db89ed7c0b65514af03 100644
--- a/aleksis/apps/chronos/frontend/messages/uk.json
+++ b/aleksis/apps/chronos/frontend/messages/uk.json
@@ -1,18 +1,28 @@
 {
   "chronos": {
-    "menu_title": "Розклади",
-    "timetable": {
-      "menu_title_all": "Усі розклади",
-      "menu_title_my": "Мій розклад"
+    "event": {
+      "amend": {
+        "cancelled": "Скасовано",
+        "rooms": "Кімнати"
+      }
+    },
+    "lessons": {
+      "menu_title_daily": "Щоденні уроки"
     },
+    "menu_title": "Розклади",
     "substitutions": {
       "menu_title": "Заміни"
     },
     "supervisions": {
       "menu_title_daily": "Щоденні спостереження"
     },
-    "lessons": {
-      "menu_title_daily": "Щоденні уроки"
+    "timetable": {
+      "menu_title_all": "Усі розклади",
+      "menu_title_my": "Мій розклад",
+      "types": {
+        "groups": "Групи",
+        "rooms": "Кімнати"
+      }
     }
   }
 }
diff --git a/aleksis/apps/chronos/models.py b/aleksis/apps/chronos/models.py
index 862e719cc2f7583cd173407f270c0b7141f41651..1d9909b70156ba52d02fdb53ad14e7bb90810618 100644
--- a/aleksis/apps/chronos/models.py
+++ b/aleksis/apps/chronos/models.py
@@ -14,7 +14,6 @@ from django.db import models
 from django.db.models import Max, Min, Q, QuerySet
 from django.db.models.functions import Coalesce
 from django.dispatch import receiver
-from django.forms import Media
 from django.http import HttpRequest
 from django.template.loader import render_to_string
 from django.urls import reverse
@@ -66,8 +65,8 @@ from aleksis.core.mixins import (
     GlobalPermissionModel,
     SchoolTermRelatedExtensibleModel,
 )
-from aleksis.core.models import CalendarEvent, DashboardWidget, Group, Person, Room, SchoolTerm
-from aleksis.core.util.core_helpers import has_person
+from aleksis.core.models import CalendarEvent, Group, Person, Room, SchoolTerm
+from aleksis.core.util.core_helpers import get_site_preferences, has_person
 
 
 class ValidityRange(ExtensibleModel):
@@ -618,45 +617,6 @@ class LessonPeriod(WeekAnnotationMixin, TeacherPropertiesMixin, ExtensibleModel)
         verbose_name_plural = _("Lesson periods")
 
 
-class TimetableWidget(DashboardWidget):
-    template = "chronos/widget.html"
-
-    def get_context(self, request):
-        from aleksis.apps.chronos.util.build import build_timetable  # noqa
-
-        context = {"has_plan": True}
-        wanted_day = TimePeriod.get_next_relevant_day(timezone.now().date(), datetime.now().time())
-
-        if has_person(request.user):
-            person = request.user.person
-            type_ = person.timetable_type
-
-            # Build timetable
-            timetable = build_timetable("person", person, wanted_day)
-
-            if type_ is None:
-                # If no student or teacher, redirect to all timetables
-                context["has_plan"] = False
-            else:
-                context["timetable"] = timetable
-                context["holiday"] = Holiday.on_day(wanted_day)
-                context["type"] = type_
-                context["day"] = wanted_day
-                context["periods"] = TimePeriod.get_times_dict()
-                context["smart"] = True
-        else:
-            context["has_plan"] = False
-
-        return context
-
-    media = Media(css={"all": ("css/chronos/timetable.css",)})
-
-    class Meta:
-        proxy = True
-        verbose_name = _("Timetable widget")
-        verbose_name_plural = _("Timetable widgets")
-
-
 class AbsenceReason(ExtensibleModel):
     short_name = models.CharField(verbose_name=_("Short name"), max_length=255, unique=True)
     name = models.CharField(verbose_name=_("Name"), blank=True, max_length=255)
@@ -1478,6 +1438,10 @@ class LessonEvent(CalendarEvent):
         """Get the description of the lesson event."""
         return render_to_string("chronos/lesson_event_description.txt", {"event": reference_object})
 
+    @classmethod
+    def get_color(cls, request: HttpRequest | None = None) -> str:
+        return get_site_preferences()["chronos__lesson_color"]
+
     @classmethod
     def value_color(cls, reference_object: LessonEvent, request: HttpRequest | None = None) -> str:
         """Get the color of the lesson event."""
@@ -1525,6 +1489,7 @@ class LessonEvent(CalendarEvent):
             "amends": cls.value_meta(reference_object.amends, request)
             if reference_object.amends
             else None,
+            "title": reference_object.title,
             "teachers": [
                 {
                     "id": t.pk,
@@ -1600,6 +1565,9 @@ class LessonEvent(CalendarEvent):
                     return objs.for_room(obj_id)
                 elif type_ == "COURSE":
                     return objs.for_course(obj_id)
+
+            if "own" in params:
+                return objs
         if request:
             return objs.for_person(request.user.person)
         return objs
@@ -1690,6 +1658,10 @@ class SupervisionEvent(LessonEvent):
             "chronos/supervision_event_description.txt", {"event": reference_object}
         )
 
+    @classmethod
+    def get_color(cls, request: HttpRequest | None = None) -> str:
+        return get_site_preferences()["chronos__supervision_color"]
+
     @classmethod
     def get_objects(
         cls, request: HttpRequest | None = None, params: dict[str, any] | None = None
diff --git a/aleksis/apps/chronos/preferences.py b/aleksis/apps/chronos/preferences.py
index 5fac608e79e12474784682a438890b511834c2b2..e75062cc2209c6a2affddbf2f52a45aaebd0f0d2 100644
--- a/aleksis/apps/chronos/preferences.py
+++ b/aleksis/apps/chronos/preferences.py
@@ -2,9 +2,17 @@ from datetime import time
 
 from django.utils.translation import gettext_lazy as _
 
+from colorfield.widgets import ColorWidget
 from dynamic_preferences.preferences import Section
-from dynamic_preferences.types import BooleanPreference, IntegerPreference, TimePreference
-
+from dynamic_preferences.types import (
+    BooleanPreference,
+    IntegerPreference,
+    ModelMultipleChoicePreference,
+    StringPreference,
+    TimePreference,
+)
+
+from aleksis.core.models import GroupType
 from aleksis.core.registries import person_preferences_registry, site_preferences_registry
 
 chronos = Section("chronos", verbose_name=_("Timetables"))
@@ -107,3 +115,41 @@ class SendNotificationsPerson(BooleanPreference):
     name = "send_notifications"
     default = True
     verbose_name = _("Send notifications for current timetable changes")
+
+
+@site_preferences_registry.register
+class GroupTypesTimetables(ModelMultipleChoicePreference):
+    section = chronos
+    name = "group_types_timetables"
+    required = False
+    default = []
+    model = GroupType
+    verbose_name = _("Group types to show in timetables")
+    help_text = _("If you leave it empty, all groups will be shown.")
+
+    def get_queryset(self):
+        return GroupType.objects.managed_and_unmanaged()
+
+
+@site_preferences_registry.register
+class LessonEventFeedColor(StringPreference):
+    """Color for the lesson calendar feed."""
+
+    section = chronos
+    name = "lesson_color"
+    default = "#a7ffeb"
+    verbose_name = _("Lesson calendar feed color")
+    widget = ColorWidget
+    required = True
+
+
+@site_preferences_registry.register
+class SupervisionEventFeedColor(StringPreference):
+    """Color for the supervision calendar feed."""
+
+    section = chronos
+    name = "supervision_color"
+    default = "#e6ee9c"
+    verbose_name = _("Supervision calendar feed color")
+    widget = ColorWidget
+    required = True
diff --git a/aleksis/apps/chronos/schema/__init__.py b/aleksis/apps/chronos/schema/__init__.py
index 9c9861ad173dbcd597d2356596b32ae763690750..bf587cb4e8283211bd52a7617bf596e16cc2a6d2 100644
--- a/aleksis/apps/chronos/schema/__init__.py
+++ b/aleksis/apps/chronos/schema/__init__.py
@@ -17,7 +17,7 @@ from aleksis.core.models import CalendarEvent, Group, Person, Room
 from aleksis.core.schema.base import DeleteMutation, FilterOrderList
 
 from ..models import LessonEvent
-from ..util.chronos_helpers import get_classes, get_rooms, get_teachers
+from ..util.chronos_helpers import get_groups, get_rooms, get_teachers
 
 
 class TimetablePersonType(DjangoObjectType):
@@ -41,15 +41,6 @@ class TimetableRoomType(DjangoObjectType):
         skip_registry = True
 
 
-# There is another unrelated CalendarEventType in aleksis/core/schema/calendar
-# This CalendarEventType is needed for the inherited amends field of LessonEvent
-# to work in the graphql query.
-class CalendarEventForLessonEventType(DjangoObjectType):
-    class Meta:
-        model = CalendarEvent
-        fields = ("id", "amends", "datetime_start", "datetime_end")
-
-
 class LessonEventType(DjangoObjectType):
     class Meta:
         model = LessonEvent
@@ -173,14 +164,14 @@ class Query(graphene.ObjectType):
         return get_teachers(info.context.user)
 
     def resolve_timetable_groups(self, info, **kwargs):
-        return get_classes(info.context.user)
+        return get_groups(info.context.user)
 
     def resolve_timetable_rooms(self, info, **kwargs):
         return get_rooms(info.context.user)
 
     def resolve_available_timetables(self, info, **kwargs):
         all_timetables = []
-        for group in get_classes(info.context.user):
+        for group in get_groups(info.context.user):
             all_timetables.append(
                 TimetableObjectType(
                     id=group.id,
@@ -191,7 +182,6 @@ class Query(graphene.ObjectType):
             )
 
         for teacher in get_teachers(info.context.user):
-            print(teacher.full_name)
             all_timetables.append(
                 TimetableObjectType(
                     id=teacher.id,
diff --git a/aleksis/apps/chronos/tables.py b/aleksis/apps/chronos/tables.py
deleted file mode 100644
index 7a60b1f6254cfef5bfaf2a415c5bfcff58f6156c..0000000000000000000000000000000000000000
--- a/aleksis/apps/chronos/tables.py
+++ /dev/null
@@ -1,122 +0,0 @@
-from __future__ import annotations
-
-from django.utils.html import format_html
-from django.utils.translation import gettext_lazy as _
-
-import django_tables2 as tables
-from django_tables2.utils import A, Accessor
-
-from .models import LessonPeriod, Supervision
-
-
-def _title_attr_from_lesson_or_supervision_state(
-    record: LessonPeriod | Supervision | None = None,
-    table: LessonsTable | SupervisionsTable | None = None,
-) -> str:
-    """Return HTML title depending on lesson or supervision state."""
-    if record.get_substitution():
-        if hasattr(record.get_substitution(), "cancelled") and record.get_substitution().cancelled:
-            return _("Lesson cancelled")
-        else:
-            return _("Substituted")
-    else:
-        return ""
-
-
-class SubstitutionColumn(tables.Column):
-    def render(self, value, record: LessonPeriod | Supervision | None = None):
-        if record.get_substitution():
-            return (
-                format_html(
-                    "<s>{}</s> → {}",
-                    value,
-                    self.substitution_accessor.resolve(record.get_substitution()),
-                )
-                if self.substitution_accessor.resolve(record.get_substitution())
-                else format_html(
-                    "<s>{}</s>",
-                    value,
-                )
-            )
-        return value
-
-    def __init__(self, *args, **kwargs):
-        self.substitution_accessor = Accessor(kwargs.pop("substitution_accessor"))
-        super().__init__(*args, **kwargs)
-
-
-class LessonStatusColumn(tables.Column):
-    def render(self, record: LessonPeriod | Supervision | None = None):
-        if record.get_substitution():
-            return (
-                format_html(
-                    '<span class="new badge green">{}</span>',
-                    _("cancelled"),
-                )
-                if hasattr(record.get_substitution(), "cancelled")
-                and record.get_substitution().cancelled
-                else format_html(
-                    '<span class="new badge orange">{}</span>',
-                    _("substituted"),
-                )
-            )
-        return ""
-
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-
-
-class LessonsTable(tables.Table):
-    """Table for daily lessons and management of substitutions."""
-
-    class Meta:
-        attrs = {"class": "highlight, striped"}
-        row_attrs = {
-            "title": _title_attr_from_lesson_or_supervision_state,
-        }
-
-    period__period = tables.Column(accessor="period__period")
-    lesson__groups = tables.Column(accessor="lesson__group_names", verbose_name=_("Groups"))
-    status = LessonStatusColumn(verbose_name=_("Status"), empty_values=())
-    lesson__teachers = SubstitutionColumn(
-        accessor="lesson__teacher_names",
-        substitution_accessor="teacher_names",
-        verbose_name=_("Teachers"),
-    )
-    lesson__subject = SubstitutionColumn(
-        accessor="lesson__subject", substitution_accessor="subject"
-    )
-    room = SubstitutionColumn(accessor="room", substitution_accessor="room")
-    edit_substitution = tables.LinkColumn(
-        "edit_substitution",
-        args=[A("id"), A("_week")],
-        text=_("Substitution"),
-        attrs={"a": {"class": "btn-flat waves-effect waves-orange"}},
-        verbose_name=_("Manage substitution"),
-    )
-
-
-class SupervisionsTable(tables.Table):
-    """Table for daily supervisions and management of substitutions."""
-
-    class Meta:
-        attrs = {"class": "highlight, striped"}
-        row_attrs = {
-            "title": _title_attr_from_lesson_or_supervision_state,
-        }
-
-    break_item = tables.Column(accessor="break_item")
-    status = LessonStatusColumn(verbose_name=_("Status"), empty_values=())
-    area = tables.Column(accessor="area")
-    teacher = SubstitutionColumn(
-        accessor="teacher",
-        substitution_accessor="teacher",
-        verbose_name=_("Teachers"),
-    )
-    edit_substitution = tables.LinkColumn(
-        "edit_supervision_substitution",
-        args=[A("id"), A("_week")],
-        text=_("Substitution"),
-        attrs={"a": {"class": "btn-flat waves-effect waves-orange"}},
-        verbose_name=_("Manage substitution"),
-    )
diff --git a/aleksis/apps/chronos/templates/chronos/all.html b/aleksis/apps/chronos/templates/chronos/all.html
deleted file mode 100644
index 01b9770567f0458913db85cabc12bd31976518e5..0000000000000000000000000000000000000000
--- a/aleksis/apps/chronos/templates/chronos/all.html
+++ /dev/null
@@ -1,59 +0,0 @@
-{# -*- engine:django -*- #}
-
-{% extends 'core/base.html' %}
-
-{% load i18n static %}
-
-{% block extra_head %}
-  <link rel="stylesheet" href="{% static 'css/chronos/timetable.css' %}">
-{% endblock %}
-
-{% block browser_title %}{% blocktrans %}All timetables{% endblocktrans %}{% endblock %}
-{% block page_title %}{% trans "All timetables" %}{% endblock %}
-
-{% block content %}
-  <div class="row">
-    <div class="col s12 m4">
-      <h2>{% trans "Teachers" %}</h2>
-
-      {% for teacher in teachers %}
-        <a class="waves-effect waves-light btn btn-timetable-quicklaunch primary"
-           href="{% url 'timetable' 'teacher' teacher.pk %}">
-          {{ teacher.short_name }}
-        </a>
-      {% empty %}
-        {% trans 'No teachers timetables available.' as message %}
-        {% include 'components/msgbox.html' with status='info' icon='mdi:alert-outline' msg=message %}
-      {% endfor %}
-    </div>
-
-    <div class="col s12 m4">
-      <h2>{% trans "Groups" %}</h2>
-
-      {% for class in classes %}
-        <a class="waves-effect waves-light btn btn-timetable-quicklaunch primary"
-           href="{% url 'timetable' 'group' class.pk %}">
-          {{ class.short_name }}
-        </a>
-      {% empty %}
-        {% trans 'No group timetables available.' as message %}
-        {% include 'components/msgbox.html' with status='info' icon='mdi:alert-outline' msg=message %}
-      {% endfor %}
-    </div>
-
-    <div class="col s12 m4">
-      <h2>{% trans "Rooms" %}</h2>
-
-      {% for room in rooms %}
-        <a class="waves-effect waves-light btn btn-timetable-quicklaunch primary"
-           href="{% url 'timetable' 'room' room.pk %}">
-          {{ room.short_name }}
-        </a>
-      {% empty %}
-        {% trans 'No room timetables available.' as message %}
-        {% include 'components/msgbox.html' with status='info' icon='mdi:alert-outline' msg=message %}
-      {% endfor %}
-    </div>
-  </div>
-
-{% endblock %}
diff --git a/aleksis/apps/chronos/templates/chronos/edit_substitution.html b/aleksis/apps/chronos/templates/chronos/edit_substitution.html
deleted file mode 100644
index 297d70139684f71d17b43f3bb4b4c875c985b9a7..0000000000000000000000000000000000000000
--- a/aleksis/apps/chronos/templates/chronos/edit_substitution.html
+++ /dev/null
@@ -1,31 +0,0 @@
-{# -*- engine:django -*- #}
-
-{% extends "core/base.html" %}
-{% load material_form i18n any_js %}
-
-{% block extra_head %}
-    {{ edit_substitution_form.media.css }}
-    {% include_css "select2-materialize" %}
-{% endblock %}
-
-{% block browser_title %}{% blocktrans %}Edit substitution.{% endblocktrans %}{% endblock %}
-{% block page_title %}{% blocktrans %}Edit substitution{% endblocktrans %}{% endblock %}
-
-{% block content %}
-  <p class="flow-text">{{ date }}: {{ lesson_period }}</p>
-  <form method="post">
-    {% csrf_token %}
-
-    {% form form=edit_substitution_form %}{% endform %}
-
-    {% include "core/partials/save_button.html" %}
-    {% if substitution %}
-      <a href="{% url 'delete_substitution' substitution.lesson_period.id substitution.week %}"
-         class="btn red waves-effect waves-light">
-        <i class="material-icons iconify left" data-icon="mdi:delete-outline"></i> {% trans "Delete" %}
-      </a>
-    {% endif %}
-  </form>
-  {% include_js "select2-materialize" %}
-  {{ edit_substitution_form.media.js }}
-{% endblock %}
diff --git a/aleksis/apps/chronos/templates/chronos/edit_supervision_substitution.html b/aleksis/apps/chronos/templates/chronos/edit_supervision_substitution.html
deleted file mode 100644
index 2ee637e87502a7e9bb45e7894e7bdbf70f056a5e..0000000000000000000000000000000000000000
--- a/aleksis/apps/chronos/templates/chronos/edit_supervision_substitution.html
+++ /dev/null
@@ -1,31 +0,0 @@
-{# -*- engine:django -*- #}
-
-{% extends "core/base.html" %}
-{% load material_form i18n any_js %}
-
-{% block extra_head %}
-    {{ edit_supervision_substitution_form.media.css }}
-    {% include_css "select2-materialize" %}
-{% endblock %}
-
-{% block browser_title %}{% blocktrans %}Edit substitution.{% endblocktrans %}{% endblock %}
-{% block page_title %}{% blocktrans %}Edit substitution{% endblocktrans %}{% endblock %}
-
-{% block content %}
-  <p class="flow-text">{{ date }}: {{ supervision }}</p>
-  <form method="post">
-    {% csrf_token %}
-
-    {% form form=edit_supervision_substitution_form %}{% endform %}
-
-    {% include "core/partials/save_button.html" %}
-    {% if substitution %}
-      <a href="{% url 'delete_supervision_substitution' substitution.supervision.id week %}"
-         class="btn red waves-effect waves-light">
-        <i class="material-icons iconify left" data-icon="mdi:delete-outline"></i> {% trans "Delete" %}
-      </a>
-    {% endif %}
-  </form>
-  {% include_js "select2-materialize" %}
-  {{ edit_supervision_substitution_form.media.js }}
-{% endblock %}
diff --git a/aleksis/apps/chronos/templates/chronos/lessons_day.html b/aleksis/apps/chronos/templates/chronos/lessons_day.html
deleted file mode 100644
index e8d0662fd9e16cff185bbd2fdca78cfdd5504fbf..0000000000000000000000000000000000000000
--- a/aleksis/apps/chronos/templates/chronos/lessons_day.html
+++ /dev/null
@@ -1,42 +0,0 @@
-{# -*- engine:django -*- #}
-
-{% extends "core/base.html" %}
-{% load i18n material_form any_js %}
-
-
-{% load render_table from django_tables2 %}
-
-{% block extra_head %}
-  {{ lesson_periods_filter.form.media.css }}
-  {% include_css "select2-materialize" %}
-{% endblock %}
-
-{% block browser_title %}{% blocktrans %}Lessons{% endblocktrans %}{% endblock %}
-{% block no_page_title %}{% endblock %}
-
-{% block content %}
-  <script type="text/javascript">
-    var dest = Urls.lessonsDay();
-  </script>
-
-  <h2>{% trans "Filter lessons" %}</h2>
-  <form method="get">
-    {% form form=lesson_periods_filter.form %}{% endform %}
-    {% trans "Search" as caption %}
-    {% include "core/partials/save_button.html" with caption=caption icon="mdi:search" %}
-  </form>
-
-  <div class="row no-margin">
-    <div class="col s12 m6 l8 no-padding">
-      <h1>{% blocktrans %}Lessons{% endblocktrans %} {{ day|date:"l" }}, {{ day }}</h1>
-    </div>
-    <div class="col s12 m6 l4 no-padding">
-      {% include "chronos/partials/datepicker.html" %}
-    </div>
-  </div>
-
-  {% render_table lessons_table %}
-
-  {% include_js "select2-materialize" %}
-  {{ lesson_periods_filter.form.media.js }}
-{% endblock %}
diff --git a/aleksis/apps/chronos/templates/chronos/my_timetable.html b/aleksis/apps/chronos/templates/chronos/my_timetable.html
deleted file mode 100644
index 1408ec233161f4e14c2022a34447526f7cb3dbb2..0000000000000000000000000000000000000000
--- a/aleksis/apps/chronos/templates/chronos/my_timetable.html
+++ /dev/null
@@ -1,66 +0,0 @@
-{# -*- engine:django -*- #}
-
-{% extends 'core/base.html' %}
-
-{% load i18n static %}
-
-{% block extra_head %}
-  <link rel="stylesheet" href="{% static 'css/chronos/timetable.css' %}">
-{% endblock %}
-
-{% block browser_title %}{% blocktrans %}My timetable{% endblocktrans %}{% endblock %}
-{% block no_page_title %}{% endblock %}
-
-{% block content %}
-  <div class="row no-margin">
-    <div class="col s12">
-      <h1>
-        {% trans "My timetable" %} <i>{{ el }}</i>
-        <span class="badge new primary-color ">{% trans "SMART PLAN" %}</span>
-      </h1>
-      <a class="btn-flat waves-effect waves-light" href="{% url "timetable" super.type.value super.el.pk %}">
-        {% trans "Show week timetable for" %} {{ super.el.short_name }}
-      </a>
-    </div>
-  </div>
-
-  <div class="row nomargin hide-on-large-only">
-    <div class="col m12 s12 l6 xl4">
-      {% include "core/partials/announcements.html" with announcements=announcements %}
-    </div>
-  </div>
-
-  <div class="row nomargin hide-on-large-med-and-down">
-    <div class="col m12 s12 l6 xl4">
-      {% include "core/partials/announcements.html" with announcements=week_announcements %}
-    </div>
-  </div>
-
-    <div class="row">
-    <div class="col s12">
-      <div class="card timetable-title-card">
-        <div class="card-content">
-            <span class="card-title">
-                {% include "chronos/partials/datepicker.html" with display_date_only=1 %}
-                <span class="show-on-medium-and-down hide-on-large-only">
-                {% if weekday.date == today %}
-                    <br/> {% include "chronos/partials/today.html" %}
-                {% endif %}
-                </span>
-            </span>
-        </div>
-      </div>
-
-    </div>
-  </div>
-
-  <div class="row hide-on-large-only">
-    <div class="timetable-plan col s12 m12 xl4">
-      {#  Lessons #}
-      {% include "chronos/partials/lessons_col.html" with lesson_periods=lesson_periods %}
-    </div>
-  </div>
-  <div class="row timetable-plan hide-on-med-and-down">
-      {% include "chronos/partials/week_timetable.html" with timetable=week_timetable active_day=day today=today %}
-  </div>
-{% endblock %}
diff --git a/aleksis/apps/chronos/templates/chronos/substitutions.html b/aleksis/apps/chronos/templates/chronos/substitutions.html
deleted file mode 100644
index 42a19e63cc3d1620343734fa6880ac2c410061f0..0000000000000000000000000000000000000000
--- a/aleksis/apps/chronos/templates/chronos/substitutions.html
+++ /dev/null
@@ -1,94 +0,0 @@
-{# -*- engine:django -*- #}
-
-{% extends 'core/base.html' %}
-
-{% load i18n static %}
-
-{% block extra_head %}
-  <link rel="stylesheet" href="{% static 'css/chronos/timetable.css' %}">
-{% endblock %}
-
-{% block browser_title %}{% blocktrans %}Substitutions{% endblocktrans %}{% endblock %}
-{% block no_page_title %}{% endblock %}
-
-{% block content %}
-  <div class="row no-margin">
-    <div class="col s10 m6 no-padding">
-      <h1>{% trans "Substitutions" %}</h1>
-    </div>
-    <div class="col s2 m6 right align-right print-icon">
-      <a class="waves-effect waves-teal btn-flat btn-flat-medium right"
-         href="{% url "substitutions_print_by_date" day.year day.month day.day %}" target="_blank">
-        <i class="material-icons iconify center" data-icon="mdi:printer-outline"></i>
-      </a>
-    </div>
-  </div>
-
-  <div class="row no-print">
-    <div class="col s12 m6 l8">
-      {% include "chronos/partials/headerbox.html" %}
-
-      {% include "core/partials/announcements.html" with announcements=announcements show_recipients=1 %}
-    </div>
-    <div class="col s12 m6 l4 no-padding">
-      {% include "chronos/partials/datepicker.html" %}
-    </div>
-  </div>
-
-  <h2 class="hide-on-small-and-down">{{ day|date:"l" }}, {{ day }}</h2>
-
-  <div class="table-container">
-    <table class="substitutions striped">
-      <thead>
-      <tr>
-        <th><i class="material-icons iconify center" data-icon="mdi:account-multiple-outline"></i></th>
-        <th><i class="material-icons iconify center" data-icon="mdi:clock-outline"></i></th>
-        <th>{% trans "Teacher" %}</th>
-        <th>{% trans "Subject" %}</th>
-        <th>{% trans "Room" %}</th>
-        <th>{% trans "Notes" %}</th>
-        <th></th>
-      </tr>
-      </thead>
-      <tbody>
-      {% if not substitutions %}
-        <td colspan="7">
-          <p class="flow-text center">
-            {% blocktrans %}No substitutions available.{% endblocktrans %}
-          </p>
-        </td>
-      {% endif %}
-      {% for item in substitutions %}
-        <tr class="{% include "chronos/partials/subs/colour.html" with item=item %}">
-          {# TODO: Extend support for purple (events) #}
-          <td>
-            {% include "chronos/partials/subs/groups.html" with type=item.type el=item.el %}
-          </td>
-          <td>
-            {% include "chronos/partials/subs/period.html" with type=item.type el=item.el item=item %}
-          </td>
-          <td>
-            {% include "chronos/partials/subs/teachers.html" with type=item.type el=item.el %}
-          </td>
-          <td>
-            {% include "chronos/partials/subs/subject.html" with type=item.type el=item.el %}
-          </td>
-          <td>
-            {% include "chronos/partials/subs/room.html" with type=item.type el=item.el %}
-          </td>
-          <td>
-            <span class="hide-on-med-and-up">
-              {% include "chronos/partials/subs/badge.html" with sub=item.el %}
-            </span>
-            {% include "chronos/partials/subs/comment.html" with el=item.el %}
-          </td>
-          <td class="hide-on-small-and-down">
-            {% include "chronos/partials/subs/badge.html" with sub=item.el %}
-          </td>
-        </tr>
-      {% endfor %}
-      </tbody>
-    </table>
-  </div>
-
-{% endblock %}
diff --git a/aleksis/apps/chronos/templates/chronos/supervisions_day.html b/aleksis/apps/chronos/templates/chronos/supervisions_day.html
deleted file mode 100644
index 8c28324ea74f5931e3eaff9603f77846c91cd723..0000000000000000000000000000000000000000
--- a/aleksis/apps/chronos/templates/chronos/supervisions_day.html
+++ /dev/null
@@ -1,38 +0,0 @@
-{# -*- engine:django -*- #}
-
-{% extends "core/base.html" %}
-{% load i18n material_form any_js %}
-
-
-{% load render_table from django_tables2 %}
-
-{% block extra_head %}
-  {{ supervisions_filter.form.media.css }}
-  {% include_css "select2-materialize" %}
-{% endblock %}
-
-{% block browser_title %}{% blocktrans %}Lessons{% endblocktrans %}{% endblock %}
-{% block no_page_title %}{% endblock %}
-
-{% block content %}
-  <h2>{% trans "Filter supervisions" %}</h2>
-  <form method="get">
-    {% form form=supervisions_filter.form %}{% endform %}
-    {% trans "Search" as caption %}
-    {% include "core/partials/save_button.html" with caption=caption icon="mdi:search" %}
-  </form>
-
-  <div class="row no-margin">
-    <div class="col s12 m6 l8 no-padding">
-      <h1>{% blocktrans %}Supervisions{% endblocktrans %} {{ day|date:"l" }}, {{ day }}</h1>
-    </div>
-    <div class="col s12 m6 l4 no-padding">
-      {% include "chronos/partials/datepicker.html" %}
-    </div>
-  </div>
-
-  {% render_table supervisions_table %}
-
-  {% include_js "select2-materialize" %}
-  {{ supervisions_filter.form.media.js }}
-{% endblock %}
diff --git a/aleksis/apps/chronos/templates/chronos/timetable.html b/aleksis/apps/chronos/templates/chronos/timetable.html
deleted file mode 100644
index 3e253eba013e9d5873c65f38867d7830394fdb38..0000000000000000000000000000000000000000
--- a/aleksis/apps/chronos/templates/chronos/timetable.html
+++ /dev/null
@@ -1,135 +0,0 @@
-{# -*- engine:django -*- #}
-
-{% extends 'core/base.html' %}
-
-{% load data_helpers rules static i18n %}
-
-{% block extra_head %}
-  <link rel="stylesheet" href="{% static 'css/chronos/timetable.css' %}">
-{% endblock %}
-
-{% block browser_title %}{% blocktrans %}Timetable{% endblocktrans %}{% endblock %}
-{% block no_page_title %}{% endblock %}
-{% block content %}
-
-  {% if smart %}
-    <script type="text/javascript" src="{% static "js/helper.js" %}"></script>
-    {{ week_select|json_script:"week_select" }}
-    <script type="text/javascript" src="{% static "js/chronos/week_select.js" %}"></script>
-  {% endif %}
-
-  <div class="row no-margin">
-    <div class="col s8 m6 l8 xl9">
-      <h1>
-        {% trans "Timetable" %} <i>{{ el }}</i>
-      </h1>
-
-      {# Show class teacher and deputy class teacher #}
-      {% if type.value == "group" and el.owners.all %}
-        <h2>{% trans "Group teachers:" %}
-          {% for teacher in el.owners.all %}
-            <span data-position="bottom" class="tooltipped"
-                  data-tooltip="{{ teacher }}">
-                            <a href="{% url "timetable" "teacher" teacher.pk %}">
-                                {{ teacher.short_name }}</a></span>{% if not forloop.last %},{% endif %}
-          {% endfor %}
-        </h2>
-      {% endif %}
-    </div>
-    <div class="col s4 m6 l4 xl3 right align-right no-print">
-      <a class="waves-effect waves-teal btn-flat btn-flat-medium right hide-on-small-and-down" href="{% url "timetable_print" type.value pk %}">
-        <i class="material-icons iconify center" data-icon="mdi:printer-outline"></i>
-      </a>
-    </div>
-  </div>
-  <div class="row">
-    {% if smart %}
-      {# Show if smart #}
-      {# Toggle button to regular and smart plan badge #}
-      <div class="row s12 m6 left">
-        <span class="badge new primary-color left smart-plan-badge">{% trans "SMART PLAN" %}</span>
-
-        <a class="waves-effect waves-light btn-flat no-print"
-           href="{% url "timetable_regular" type.value pk "regular" %}">
-          <i class="material-icons iconify left" data-icon="mdi:play-box-outline"></i>
-          {% trans "Show regular timetable" %}
-        </a>
-
-        {% has_perm "alsijil.view_week_rule" user as can_view_week_view %}
-        {% if is_alsijil_installed and can_view_week_view %}
-          <a class="waves-effect waves-light btn-flat no-print"
-            href="{% url "week_view_by_week" year=week.year week=week.week %}">
-            <i class="material-icons iconify left" data-icon="mdi:book-open"></i>
-            {% trans "View class register of this week" %}
-          </a> 
-        {% endif %}
-      </div>
-
-      {# Week select #}
-      {% include "chronos/partials/week_select.html" with wanted_week=week %}
-
-    {% else %}
-      {# Show if regular #}
-      <a class="waves-effect waves-light btn-flat no-print"
-         href="{% url "timetable" type.value pk %}">
-        <i class="material-icons iconify left" data-icon="mdi:play-box-outline"></i>
-        {% trans "Show SMART PLAN" %}
-      </a>
-
-      {% has_perm "alsijil.view_week_rule" user as can_view_week_view %}
-      {% if is_alsijil_installed and can_view_week_view %}
-        <a class="waves-effect waves-light btn-flat no-print"
-          href="{% url "week_view_by_week" year=week.year week=week.week %}">
-          <i class="material-icons iconify left" data-icon="mdi:book-open"></i>
-          {% trans "View class register of this week" %}
-        </a> 
-      {% endif %}
-    {% endif %}
-  </div>
-
-  {% include "core/partials/announcements.html" with announcements=announcements show_interval=1 %}
-
-  {# show full timetable on tablets, laptops and pcs #}
-  <div class="timetable-plan hide-on-small-and-down">
-    {% include "chronos/partials/week_timetable.html" %}
-  </div>
-
-  {# show 5 seperate ones on mobiles #}
-  <div class="timetable-plan hide-on-med-and-up">
-    {% for weekday in weekdays %}
-      <div class="card timetable-mobile-title-card">
-        <div class="card-content">
-          <span class="card-title">
-            {{ weekday.name }}
-          </span>
-          {% if smart %}
-                {{ weekday.date }}
-                {% if weekday.holiday %}
-                  <br/>{% include "chronos/partials/holiday.html" with holiday=weekday.holiday %}
-                {% endif %}
-              {% endif %}
-        </div>
-      </div>
-      {% for row in timetable %}
-        <div class="row">
-          <div class="col s4">
-            {% include "chronos/partials/period_time.html" with period=row.period periods=periods %}
-          </div>
-
-          {% for col in row.cols %}
-            {% if forloop.counter0 == weekday.key %}
-              <div class="col s8">
-                {# A lesson #}
-                {% if row.type == "period" %}
-                  {% include "chronos/partials/elements.html" with elements=col %}
-                {% else %}
-                  {% include "chronos/partials/supervision.html" with supervision=col %}
-                {% endif %}
-              </div>
-            {% endif %}
-          {% endfor %}
-        </div>
-      {% endfor %}
-    {% endfor %}
-  </div>
-{% endblock %}
diff --git a/aleksis/apps/chronos/templates/chronos/widget.html b/aleksis/apps/chronos/templates/chronos/widget.html
deleted file mode 100644
index 10d3c19aa14d1ec68a25d2f327d51ab3ef0a341a..0000000000000000000000000000000000000000
--- a/aleksis/apps/chronos/templates/chronos/widget.html
+++ /dev/null
@@ -1,30 +0,0 @@
-{# -*- engine:django -*- #}
-
-{% load i18n static humanize %}
-
-<div class="card">
-  <div class="card-content">
-    <span class="card-title">
-      {% blocktrans with day=day|naturalday:"l" %}
-        My timetable for {{ day }}
-      {% endblocktrans %}
-    </span>
-    <div class="timetable-plan">
-      {% if has_plan %}
-        {% include "chronos/partials/lessons_col.html" with lesson_periods=lesson_periods %}
-      {% else %}
-        <figure class="alert warning">
-          <i class="material-icons iconify left" data-icon="mdi:alert-outline"></i>
-          {% blocktrans %}
-          There is no timetable linked to your person.
-          {% endblocktrans %}
-        </figure>
-      {% endif %}
-    </div>
-  </div>
-  {% if has_plan %}
-    <div class="card-action">
-      <a href="{% url "my_timetable" %}">{% trans "Go to smart plan" %}</a>
-    </div>
-  {% endif %}
-</div>
diff --git a/aleksis/apps/chronos/tests/test_notifications.py b/aleksis/apps/chronos/tests/test_notifications.py
deleted file mode 100644
index 2e2393cb2b3fa962613615115ce57966b538af7a..0000000000000000000000000000000000000000
--- a/aleksis/apps/chronos/tests/test_notifications.py
+++ /dev/null
@@ -1,269 +0,0 @@
-from datetime import date, time
-
-from django.db import transaction
-from django.db.models.signals import m2m_changed, post_delete, post_save, pre_delete
-from django.test import TransactionTestCase, override_settings
-
-import pytest
-
-from aleksis.apps.chronos.models import (
-    Event,
-    ExtraLesson,
-    Lesson,
-    LessonPeriod,
-    LessonSubstitution,
-    Subject,
-    SupervisionSubstitution,
-    TimePeriod,
-)
-from aleksis.apps.chronos.util.change_tracker import TimetableDataChangeTracker
-from aleksis.core.models import Group, Person, Room, SchoolTerm
-
-pytestmark = pytest.mark.django_db
-
-
-@override_settings(CELERY_BROKER_URL="memory://localhost//")
-class NotificationTests(TransactionTestCase):
-    serialized_rollback = True
-
-    def setUp(self):
-        self.school_term = SchoolTerm.objects.create(
-            date_start=date(2020, 1, 1), date_end=date(2020, 12, 31)
-        )
-
-        self.teacher_a = Person.objects.create(
-            first_name="Teacher", last_name="A", short_name="A", email="test1@example.org"
-        )
-        self.teacher_b = Person.objects.create(
-            first_name="Teacher", last_name="B", short_name="B", email="test2@example.org"
-        )
-
-        self.student_a = Person.objects.create(
-            first_name="Student", last_name="A", email="test3@example.org"
-        )
-        self.student_b = Person.objects.create(
-            first_name="Student", last_name="B", email="test4@example.org"
-        )
-        self.student_c = Person.objects.create(
-            first_name="Student", last_name="C", email="test5@example.org"
-        )
-        self.student_d = Person.objects.create(
-            first_name="Student", last_name="D", email="test6@example.org"
-        )
-        self.student_e = Person.objects.create(
-            first_name="Student", last_name="E", email="test7@example.org"
-        )
-
-        self.group_a = Group.objects.create(
-            name="Class 9a", short_name="9a", school_term=self.school_term
-        )
-        self.group_a.owners.add(self.teacher_a)
-        self.group_a.members.add(self.student_a, self.student_b, self.student_c)
-        self.group_b = Group.objects.create(
-            name="Class 9b", short_name="9b", school_term=self.school_term
-        )
-        self.group_b.owners.add(self.teacher_b)
-        self.group_b.members.add(self.student_c, self.student_d, self.student_e)
-
-        self.time_period_a = TimePeriod.objects.create(
-            weekday=0, period=1, time_start=time(8, 0), time_end=time(9, 0)
-        )
-        self.time_period_b = TimePeriod.objects.create(
-            weekday=1, period=2, time_start=time(9, 0), time_end=time(10, 0)
-        )
-
-        self.subject_a = Subject.objects.create(name="English", short_name="En")
-        self.subject_b = Subject.objects.create(name="Deutsch", short_name="De")
-
-        self.room_a = Room.objects.create(short_name="004", name="Room 0.04")
-        self.room_b = Room.objects.create(short_name="005", name="Room 0.05")
-
-        self.lesson = Lesson.objects.create(subject=self.subject_a)
-        self.lesson.groups.set([self.group_a])
-        self.lesson.teachers.set([self.teacher_a])
-
-        self.period_1 = LessonPeriod.objects.create(
-            period=self.time_period_a, room=self.room_a, lesson=self.lesson
-        )
-        self.period_2 = LessonPeriod.objects.create(
-            period=self.time_period_b, room=self.room_a, lesson=self.lesson
-        )
-
-    def _parse_receivers(self, receivers):
-        return [str(r[1]) for r in receivers]
-
-    def test_signal_registration(self):
-        for model in [Event, LessonSubstitution, ExtraLesson, SupervisionSubstitution]:
-            assert "TimetableDataChangeTracker._handle_save" not in "".join(
-                [str(r) for r in post_save._live_receivers(model)]
-            )
-
-        for model in [Event, LessonSubstitution, ExtraLesson, SupervisionSubstitution]:
-            assert "TimetableDataChangeTracker._handle_delete" not in "".join(
-                [str(r) for r in post_delete._live_receivers(model)]
-            )
-
-        assert "TimetableDataChangeTracker._handle_m2m_changed" not in "".join(
-            [str(r) for r in m2m_changed._live_receivers(LessonSubstitution.teachers.through)]
-        )
-        assert "TimetableDataChangeTracker._handle_m2m_changed" not in "".join(
-            [str(r) for r in m2m_changed._live_receivers(Event.teachers.through)]
-        )
-        assert "TimetableDataChangeTracker._handle_m2m_changed" not in "".join(
-            [str(r) for r in m2m_changed._live_receivers(Event.groups.through)]
-        )
-        assert "TimetableDataChangeTracker._handle_m2m_changed" not in "".join(
-            [str(r) for r in m2m_changed._live_receivers(ExtraLesson.teachers.through)]
-        )
-        assert "TimetableDataChangeTracker._handle_m2m_changed" not in "".join(
-            [str(r) for r in m2m_changed._live_receivers(ExtraLesson.groups.through)]
-        )
-        assert "TimetableDataChangeTracker._handle_m2m_changed" not in "".join(
-            [str(r) for r in m2m_changed._live_receivers(ExtraLesson.groups.through)]
-        )
-
-        with transaction.atomic():
-            tracker = TimetableDataChangeTracker()
-
-            for model in [Event, LessonSubstitution, ExtraLesson, SupervisionSubstitution]:
-                assert "TimetableDataChangeTracker._handle_save" in "".join(
-                    [str(r) for r in post_save._live_receivers(model)]
-                )
-
-            for model in [Event, LessonSubstitution, ExtraLesson, SupervisionSubstitution]:
-                assert "TimetableDataChangeTracker._handle_delete" in "".join(
-                    [str(r) for r in pre_delete._live_receivers(model)]
-                )
-
-            assert "TimetableDataChangeTracker._handle_m2m_changed" in "".join(
-                [str(r) for r in m2m_changed._live_receivers(LessonSubstitution.teachers.through)]
-            )
-            assert "TimetableDataChangeTracker._handle_m2m_changed" in "".join(
-                [str(r) for r in m2m_changed._live_receivers(Event.teachers.through)]
-            )
-            assert "TimetableDataChangeTracker._handle_m2m_changed" in "".join(
-                [str(r) for r in m2m_changed._live_receivers(Event.groups.through)]
-            )
-            assert "TimetableDataChangeTracker._handle_m2m_changed" in "".join(
-                [str(r) for r in m2m_changed._live_receivers(ExtraLesson.teachers.through)]
-            )
-            assert "TimetableDataChangeTracker._handle_m2m_changed" in "".join(
-                [str(r) for r in m2m_changed._live_receivers(ExtraLesson.groups.through)]
-            )
-
-    def test_outside_transaction(self):
-        with pytest.raises(RuntimeError):
-            TimetableDataChangeTracker()
-
-    def test_create_detection(self):
-        with transaction.atomic():
-            tracker = TimetableDataChangeTracker()
-
-            assert not tracker.changes
-
-            lesson_substitution = LessonSubstitution.objects.create(
-                week=20, year=2020, lesson_period=self.period_1, cancelled=True
-            )
-
-            assert tracker.changes
-
-            assert len(tracker.changes) == 1
-            change = tracker.changes[tracker.get_instance_key(lesson_substitution)]
-            assert change.instance == lesson_substitution
-            assert change.created
-            assert not change.deleted
-            assert not change.changed_fields
-
-            lesson_substitution.cancelled = False
-            lesson_substitution.subject = self.subject_b
-            lesson_substitution.save()
-
-            assert len(tracker.changes) == 1
-            change = tracker.changes[tracker.get_instance_key(lesson_substitution)]
-            assert change.instance == lesson_substitution
-            assert change.created
-            assert not change.deleted
-            assert change.changed_fields
-
-    def test_change_detection(self):
-        with transaction.atomic():
-            lesson_substitution = LessonSubstitution.objects.create(
-                week=20, year=2020, lesson_period=self.period_1, cancelled=True
-            )
-
-            tracker = TimetableDataChangeTracker()
-
-            assert not tracker.changes
-
-            lesson_substitution.cancelled = False
-            lesson_substitution.subject = self.subject_b
-            lesson_substitution.save()
-
-            assert len(tracker.changes) == 1
-            change = tracker.changes[tracker.get_instance_key(lesson_substitution)]
-            assert change.instance == lesson_substitution
-            assert not change.created
-            assert not change.deleted
-            assert set(change.changed_fields.keys()) == {"cancelled", "subject_id"}
-
-            assert change.changed_fields["cancelled"]
-            assert change.changed_fields["subject_id"] is None
-
-            lesson_substitution.teachers.add(self.teacher_a)
-
-            assert len(tracker.changes) == 1
-            change = tracker.changes[tracker.get_instance_key(lesson_substitution)]
-            assert change.instance == lesson_substitution
-            assert not change.created
-            assert not change.deleted
-            assert set(change.changed_fields.keys()) == {"cancelled", "subject_id", "teachers"}
-
-            assert change.changed_fields["teachers"] == []
-
-            lesson_substitution.teachers.remove(self.teacher_a)
-
-            assert len(tracker.changes) == 1
-            change = tracker.changes[tracker.get_instance_key(lesson_substitution)]
-            assert change.instance == lesson_substitution
-            assert not change.created
-            assert not change.deleted
-            assert set(change.changed_fields.keys()) == {"cancelled", "subject_id", "teachers"}
-
-            assert change.changed_fields["teachers"] == []
-
-        with transaction.atomic():
-            lesson_substitution.teachers.add(self.teacher_a)
-
-            tracker = TimetableDataChangeTracker()
-
-            lesson_substitution.teachers.remove(self.teacher_a)
-
-            assert len(tracker.changes) == 1
-            change = tracker.changes[tracker.get_instance_key(lesson_substitution)]
-            assert change.instance == lesson_substitution
-            assert not change.created
-            assert not change.deleted
-            assert set(change.changed_fields.keys()) == {"teachers"}
-
-            assert change.changed_fields["teachers"] == [self.teacher_a]
-
-    def test_delete_detected(self):
-        lesson_substitution = LessonSubstitution.objects.create(
-            week=20, year=2020, lesson_period=self.period_1, cancelled=True
-        )
-
-        with transaction.atomic():
-            tracker = TimetableDataChangeTracker()
-
-            pk = lesson_substitution.pk
-
-            assert not tracker.changes
-
-            lesson_substitution.delete()
-
-            assert len(tracker.changes) == 1
-            change = tracker.changes[f"lessonsubstitution_{pk}"]
-            assert change.instance == lesson_substitution
-            assert not change.created
-            assert change.deleted
-            assert not change.changed_fields
diff --git a/aleksis/apps/chronos/urls.py b/aleksis/apps/chronos/urls.py
index e4cf26197a1e45fefac0bc16021fc05196ddc109..7d55323042b9a23438975c589bd23967c3cbb396 100644
--- a/aleksis/apps/chronos/urls.py
+++ b/aleksis/apps/chronos/urls.py
@@ -3,78 +3,9 @@ from django.urls import path
 from . import views
 
 urlpatterns = [
-    path("", views.all_timetables, name="all_timetables"),
-    path("timetable/my/", views.my_timetable, name="my_timetable"),
-    path(
-        "timetable/my/<int:year>/<int:month>/<int:day>/",
-        views.my_timetable,
-        name="my_timetable_by_date",
-    ),
-    path("timetable/<str:type_>/<int:pk>/", views.timetable, name="timetable"),
-    path(
-        "timetable/<str:type_>/<int:pk>/<int:year>/<int:week>/",
-        views.timetable,
-        name="timetable_by_week",
-    ),
-    path(
-        "timetable/<str:type_>/<int:pk>/print/",
-        views.timetable,
-        {"is_print": True},
-        name="timetable_print",
-    ),
-    path(
-        "timetable/<str:type_>/<int:pk>/<str:regular>/",
-        views.timetable,
-        name="timetable_regular",
-    ),
-    path("lessons/", views.lessons_day, name="lessons_day"),
-    path(
-        "lessons/<int:year>/<int:month>/<int:day>/",
-        views.lessons_day,
-        name="lessons_day_by_date",
-    ),
-    path(
-        "lessons/<int:id_>/<int:week>/substitution/",
-        views.edit_substitution,
-        name="edit_substitution",
-    ),
-    path(
-        "lessons/<int:id_>/<int:week>/substitution/delete/",
-        views.delete_substitution,
-        name="delete_substitution",
-    ),
-    path("substitutions/", views.substitutions, name="substitutions"),
     path(
         "substitutions/print/",
-        views.substitutions,
-        {"is_print": True},
+        views.substitutions_print,
         name="substitutions_print",
     ),
-    path(
-        "substitutions/<int:year>/<int:month>/<int:day>/",
-        views.substitutions,
-        name="substitutions_by_date",
-    ),
-    path(
-        "substitutions/<int:year>/<int:month>/<int:day>/print/",
-        views.substitutions,
-        {"is_print": True},
-        name="substitutions_print_by_date",
-    ),
-    path("supervisions/", views.supervisions_day, name="supervisions_day"),
-    path(
-        "supervisions/<int:year>/<int:month>/<int:day>/",
-        views.supervisions_day,
-        name="supervisions_day_by_date",
-    ),
-    path(
-        "supervisions/<int:id_>/<int:week>/substitution/",
-        views.edit_supervision_substitution,
-        name="edit_supervision_substitution",
-    ),
-    path(
-        "supervisions/<int:id_>/<int:week>/substitution/delete/",
-        views.delete_supervision_substitution,
-        name="delete_supervision_substitution",
-    ),
 ]
diff --git a/aleksis/apps/chronos/util/predicates.py b/aleksis/apps/chronos/util/predicates.py
index f75adbe027b2b46e13440e993527e283e9ed6941..8549177f625f35aa12358c050d8f30c171c9de06 100644
--- a/aleksis/apps/chronos/util/predicates.py
+++ b/aleksis/apps/chronos/util/predicates.py
@@ -6,7 +6,7 @@ from rules import predicate
 from aleksis.core.models import Group, Person, Room
 from aleksis.core.util.predicates import has_any_object, has_global_perm, has_object_perm
 
-from .chronos_helpers import get_classes, get_rooms, get_teachers
+from .chronos_helpers import get_groups, get_rooms, get_teachers
 
 
 @predicate
@@ -105,4 +105,4 @@ def has_room_timetable_perm(user: User, obj: Room) -> bool:
 @predicate
 def has_any_timetable_object(user: User) -> bool:
     """Predicate which checks whether there are any timetables the user is allowed to access."""
-    return get_classes(user).exists() or get_rooms(user).exists() or get_teachers(user).exists()
+    return get_groups(user).exists() or get_rooms(user).exists() or get_teachers(user).exists()
diff --git a/aleksis/apps/chronos/views.py b/aleksis/apps/chronos/views.py
index 8bd3307977dbe5a625df0223edf7a85044ca5f78..a45997ca580db9f8fa442be52d88054055e2661d 100644
--- a/aleksis/apps/chronos/views.py
+++ b/aleksis/apps/chronos/views.py
@@ -1,468 +1,25 @@
-from datetime import datetime
 from typing import Optional
 
-from django.apps import apps
-from django.db.models import FilteredRelation, Q
-from django.http import HttpRequest, HttpResponse, HttpResponseNotFound
-from django.shortcuts import get_object_or_404, redirect, render
-from django.urls import reverse
-from django.utils import timezone
-from django.utils.translation import gettext as _
-from django.views.decorators.cache import never_cache
+from django.http import HttpRequest, HttpResponse
 
-import reversion
-from django_tables2 import RequestConfig
 from rules.contrib.views import permission_required
 
 from aleksis.core.decorators import pwa_cache
-from aleksis.core.models import Announcement
-from aleksis.core.util import messages
-from aleksis.core.util.core_helpers import has_person
 from aleksis.core.util.pdf import render_pdf
 
-from .filters import LessonPeriodFilter, SupervisionFilter
-from .forms import LessonSubstitutionForm, SupervisionSubstitutionForm
-from .managers import TimetableType
-from .models import Holiday, LessonPeriod, Supervision, TimePeriod
-from .tables import LessonsTable, SupervisionsTable
-from .util.build import build_timetable, build_weekdays
-from .util.change_tracker import TimetableDataChangeTracker
 from .util.chronos_helpers import (
-    get_classes,
-    get_el_by_pk,
-    get_rooms,
-    get_substitution_by_id,
     get_substitutions_context_data,
-    get_supervision_substitution_by_id,
-    get_teachers,
 )
-from .util.date import CalendarWeek, get_weeks_for_year, week_weekday_to_date
-from .util.js import date_unix
-
-
-@pwa_cache
-@permission_required("chronos.view_timetable_overview_rule")
-def all_timetables(request: HttpRequest) -> HttpResponse:
-    """View all timetables for persons, groups and rooms."""
-    context = {}
-
-    user = request.user
-    teachers, classes, rooms = get_teachers(user), get_classes(user), get_rooms(user)
-
-    context["teachers"] = teachers
-    context["classes"] = classes
-    context["rooms"] = rooms
-
-    return render(request, "chronos/all.html", context)
-
-
-@pwa_cache
-@permission_required("chronos.view_my_timetable_rule")
-def my_timetable(
-    request: HttpRequest,
-    year: Optional[int] = None,
-    month: Optional[int] = None,
-    day: Optional[int] = None,
-) -> HttpResponse:
-    """View personal timetable on a specified date."""
-    context = {}
-
-    if day:
-        wanted_day = timezone.datetime(year=year, month=month, day=day).date()
-        wanted_day = TimePeriod.get_next_relevant_day(wanted_day)
-    else:
-        wanted_day = TimePeriod.get_next_relevant_day(timezone.now().date(), datetime.now().time())
-
-    wanted_week = CalendarWeek.from_date(wanted_day)
-
-    if has_person(request.user):
-        person = request.user.person
-        type_ = person.timetable_type
-
-        # Build timetable
-        timetable = build_timetable("person", person, wanted_day)
-        week_timetable = build_timetable("person", person, wanted_week)
-
-        if type_ is None:
-            # If no student or teacher, redirect to all timetables
-            return redirect("all_timetables")
-
-        super_el = person.timetable_object
-
-        context["timetable"] = timetable
-        context["week_timetable"] = week_timetable
-        context["holiday"] = Holiday.on_day(wanted_day)
-        context["super"] = {"type": type_, "el": super_el}
-        context["type"] = type_
-        context["day"] = wanted_day
-        context["today"] = timezone.now().date()
-        context["week"] = wanted_week
-        context["periods"] = TimePeriod.get_times_dict()
-        context["smart"] = True
-        context["announcements"] = (
-            Announcement.for_timetables().on_date(wanted_day).for_person(person)
-        )
-        context["week_announcements"] = (
-            Announcement.for_timetables()
-            .within_days(wanted_week[0], wanted_week[6])
-            .for_person(person)
-        )
-        context["weekdays"] = build_weekdays(TimePeriod.WEEKDAY_CHOICES, wanted_week)
-        context["weekdays_short"] = build_weekdays(TimePeriod.WEEKDAY_CHOICES_SHORT, wanted_week)
-        context["url_prev"], context["url_next"] = TimePeriod.get_prev_next_by_day(
-            wanted_day, "my_timetable_by_date"
-        )
-
-        return render(request, "chronos/my_timetable.html", context)
-    else:
-        return redirect("all_timetables")
-
-
-@pwa_cache
-@permission_required("chronos.view_timetable_rule", fn=get_el_by_pk)
-def timetable(
-    request: HttpRequest,
-    type_: str,
-    pk: int,
-    year: Optional[int] = None,
-    week: Optional[int] = None,
-    regular: Optional[str] = None,
-    is_print: bool = False,
-) -> HttpResponse:
-    """View a selected timetable for a person, group or room."""
-    context = {}
-
-    is_smart = regular != "regular"
-
-    if is_print:
-        is_smart = False
-
-    el = get_el_by_pk(request, type_, pk, prefetch=True)
-
-    if isinstance(el, HttpResponseNotFound):
-        return HttpResponseNotFound()
-
-    type_ = TimetableType.from_string(type_)
-
-    if year and week:
-        wanted_week = CalendarWeek(year=year, week=week)
-    else:
-        wanted_week = TimePeriod.get_relevant_week_from_datetime()
-
-    # Build timetable
-    timetable = build_timetable(type_, el, wanted_week, with_holidays=is_smart)
-    context["timetable"] = timetable
-
-    # Add time periods
-    context["periods"] = TimePeriod.get_times_dict()
-
-    # Build lists with weekdays and corresponding dates (long and short variant)
-    context["weekdays"] = build_weekdays(
-        TimePeriod.WEEKDAY_CHOICES, wanted_week, with_holidays=is_smart
-    )
-    context["weekdays_short"] = build_weekdays(
-        TimePeriod.WEEKDAY_CHOICES_SHORT, wanted_week, with_holidays=is_smart
-    )
-
-    context["weeks"] = get_weeks_for_year(year=wanted_week.year)
-    context["week"] = wanted_week
-    context["type"] = type_
-    context["pk"] = pk
-    context["el"] = el
-    context["smart"] = is_smart
-    context["week_select"] = {
-        "year": wanted_week.year,
-        "dest": reverse(
-            "timetable_by_week",
-            args=[type_.value, pk, wanted_week.year, wanted_week.week],
-        )[::-1]
-        .replace(str(wanted_week.week)[::-1], "cw"[::-1], 1)
-        .replace(str(wanted_week.year)[::-1], "year"[::-1], 1)[::-1],
-    }
-
-    if is_smart:
-        start = wanted_week[TimePeriod.weekday_min]
-        stop = wanted_week[TimePeriod.weekday_max]
-        context["announcements"] = (
-            Announcement.for_timetables().relevant_for(el).within_days(start, stop)
-        )
-
-    week_prev = wanted_week - 1
-    week_next = wanted_week + 1
-
-    context["url_prev"] = reverse(
-        "timetable_by_week", args=[type_.value, pk, week_prev.year, week_prev.week]
-    )
-    context["url_next"] = reverse(
-        "timetable_by_week", args=[type_.value, pk, week_next.year, week_next.week]
-    )
-
-    if apps.is_installed("aleksis.apps.alsijil"):
-        context["is_alsijil_installed"] = True
-
-    if is_print:
-        context["back_url"] = reverse(
-            "timetable_by_week",
-            args=[type_.value, pk, wanted_week.year, wanted_week.week],
-        )
-        return render_pdf(request, "chronos/timetable_print.html", context)
-    else:
-        return render(request, "chronos/timetable.html", context)
-
-
-@pwa_cache
-@permission_required("chronos.view_lessons_day_rule")
-def lessons_day(
-    request: HttpRequest,
-    year: Optional[int] = None,
-    month: Optional[int] = None,
-    day: Optional[int] = None,
-) -> HttpResponse:
-    """View all lessons taking place on a specified day."""
-    context = {}
-
-    if day:
-        wanted_day = timezone.datetime(year=year, month=month, day=day).date()
-        wanted_day = TimePeriod.get_next_relevant_day(wanted_day)
-    else:
-        wanted_day = TimePeriod.get_next_relevant_day(timezone.now().date(), datetime.now().time())
-
-    # Get lessons
-    lesson_periods = LessonPeriod.objects.on_day(wanted_day)
-
-    # Get filter
-    lesson_periods_filter = LessonPeriodFilter(
-        request.GET,
-        queryset=lesson_periods.annotate(
-            current_substitution=FilteredRelation(
-                "substitutions",
-                condition=(
-                    Q(substitutions__week=wanted_day.isocalendar()[1], substitutions__year=year)
-                ),
-            )
-        ),
-        weekday=wanted_day.weekday(),
-    )
-    context["lesson_periods_filter"] = lesson_periods_filter
-
-    # Build table
-    lessons_table = LessonsTable(lesson_periods_filter.qs)
-    RequestConfig(request).configure(lessons_table)
-
-    context["lessons_table"] = lessons_table
-    context["day"] = wanted_day
-    context["lesson_periods"] = lesson_periods
-
-    context["datepicker"] = {
-        "date": date_unix(wanted_day),
-        "dest": reverse("lessons_day"),
-    }
-
-    context["url_prev"], context["url_next"] = TimePeriod.get_prev_next_by_day(
-        wanted_day, "lessons_day_by_date"
-    )
-
-    return render(request, "chronos/lessons_day.html", context)
-
-
-@never_cache
-@permission_required("chronos.edit_substitution_rule", fn=get_substitution_by_id)
-def edit_substitution(request: HttpRequest, id_: int, week: int) -> HttpResponse:
-    """View a form to edit a substitution lessen."""
-    context = {}
-
-    lesson_period = get_object_or_404(LessonPeriod, pk=id_)
-    wanted_week = lesson_period.lesson.get_calendar_week(week)
-    context["lesson_period"] = lesson_period
-    day = week_weekday_to_date(wanted_week, lesson_period.period.weekday)
-    context["date"] = day
-
-    lesson_substitution = get_substitution_by_id(request, id_, week)
-
-    if lesson_substitution:
-        edit_substitution_form = LessonSubstitutionForm(
-            request, request.POST or None, instance=lesson_substitution
-        )
-    else:
-        edit_substitution_form = LessonSubstitutionForm(
-            request,
-            request.POST or None,
-        )
-
-    context["substitution"] = lesson_substitution
-
-    if request.method == "POST" and edit_substitution_form.is_valid():
-        with reversion.create_revision(atomic=True):
-            TimetableDataChangeTracker()
-
-            lesson_substitution = edit_substitution_form.save(commit=False)
-            if not lesson_substitution.pk:
-                lesson_substitution.lesson_period = lesson_period
-                lesson_substitution.week = wanted_week.week
-                lesson_substitution.year = wanted_week.year
-            lesson_substitution.save()
-            edit_substitution_form.save_m2m()
-
-            messages.success(request, _("The substitution has been saved."))
-
-        return redirect("lessons_day_by_date", year=day.year, month=day.month, day=day.day)
-
-    context["edit_substitution_form"] = edit_substitution_form
-
-    return render(request, "chronos/edit_substitution.html", context)
-
-
-@permission_required("chronos.delete_substitution_rule", fn=get_substitution_by_id)
-def delete_substitution(request: HttpRequest, id_: int, week: int) -> HttpResponse:
-    """Delete a substitution lesson.
-
-    Redirects back to substition list on success.
-    """
-    lesson_period = get_object_or_404(LessonPeriod, pk=id_)
-    wanted_week = lesson_period.lesson.get_calendar_week(week)
-
-    get_substitution_by_id(request, id_, week).delete()
-
-    messages.success(request, _("The substitution has been deleted."))
-
-    date = wanted_week[lesson_period.period.weekday]
-    return redirect("lessons_day_by_date", year=date.year, month=date.month, day=date.day)
 
 
 @pwa_cache
 @permission_required("chronos.view_substitutions_rule")
-def substitutions(
+def substitutions_print(
     request: HttpRequest,
     year: Optional[int] = None,
     month: Optional[int] = None,
     day: Optional[int] = None,
-    is_print: bool = False,
 ) -> HttpResponse:
     """View all substitutions on a specified day."""
-    context = get_substitutions_context_data(request, year, month, day, is_print)
-    if not is_print:
-        return render(request, "chronos/substitutions.html", context)
-    else:
-        return render_pdf(request, "chronos/substitutions_print.html", context)
-
-
-@pwa_cache
-@permission_required("chronos.view_supervisions_day_rule")
-def supervisions_day(
-    request: HttpRequest,
-    year: Optional[int] = None,
-    month: Optional[int] = None,
-    day: Optional[int] = None,
-) -> HttpResponse:
-    """View all supervisions taking place on a specified day."""
-    context = {}
-
-    if day:
-        wanted_day = timezone.datetime(year=year, month=month, day=day).date()
-        wanted_day = TimePeriod.get_next_relevant_day(wanted_day)
-    else:
-        wanted_day = TimePeriod.get_next_relevant_day(timezone.now().date(), datetime.now().time())
-
-    # Get supervisions
-    supervisions = (
-        Supervision.objects.on_day(wanted_day)
-        .filter_by_weekday(wanted_day.weekday())
-        .order_by("break_item__before_period__period")
-    )
-
-    # Get filter
-    supervisions_filter = SupervisionFilter(
-        request.GET,
-        queryset=supervisions.annotate(
-            current_substitution=FilteredRelation(
-                "substitutions",
-                condition=(Q(substitutions__date=wanted_day)),
-            )
-        ),
-    )
-    context["supervisions_filter"] = supervisions_filter
-
-    # Build table
-    supervisions_table = SupervisionsTable(
-        supervisions_filter.qs.annotate_week(week=CalendarWeek.from_date(wanted_day))
-    )
-    RequestConfig(request).configure(supervisions_table)
-
-    context["supervisions_table"] = supervisions_table
-    context["day"] = wanted_day
-    context["supervisions"] = supervisions
-
-    context["datepicker"] = {
-        "date": date_unix(wanted_day),
-        "dest": reverse("supervisions_day"),
-    }
-
-    context["url_prev"], context["url_next"] = TimePeriod.get_prev_next_by_day(
-        wanted_day, "supervisions_day_by_date"
-    )
-
-    return render(request, "chronos/supervisions_day.html", context)
-
-
-@never_cache
-@permission_required("chronos.edit_supervision_substitution_rule")
-def edit_supervision_substitution(request: HttpRequest, id_: int, week: int) -> HttpResponse:
-    """View a form to edit a supervision substitution."""
-    context = {}
-
-    supervision = get_object_or_404(Supervision, pk=id_)
-    wanted_week = supervision.get_calendar_week(week)
-    context["week"] = week
-    context["supervision"] = supervision
-    date = week_weekday_to_date(wanted_week, supervision.break_item.weekday)
-    context["date"] = date
-
-    supervision_substitution = get_supervision_substitution_by_id(request, id_, date)
-
-    if supervision_substitution:
-        edit_supervision_substitution_form = SupervisionSubstitutionForm(
-            request, request.POST or None, instance=supervision_substitution
-        )
-    else:
-        edit_supervision_substitution_form = SupervisionSubstitutionForm(
-            request,
-            request.POST or None,
-        )
-
-    context["substitution"] = supervision_substitution
-
-    if request.method == "POST" and edit_supervision_substitution_form.is_valid():
-        with reversion.create_revision(atomic=True):
-            TimetableDataChangeTracker()
-
-            supervision_substitution = edit_supervision_substitution_form.save(commit=False)
-            if not supervision_substitution.pk:
-                supervision_substitution.supervision = supervision
-                supervision_substitution.date = date
-            supervision_substitution.save()
-            edit_supervision_substitution_form.save_m2m()
-
-            messages.success(request, _("The substitution has been saved."))
-
-        return redirect("supervisions_day_by_date", year=date.year, month=date.month, day=date.day)
-
-    context["edit_supervision_substitution_form"] = edit_supervision_substitution_form
-
-    return render(request, "chronos/edit_supervision_substitution.html", context)
-
-
-@permission_required("chronos.delete_supervision_substitution_rule")
-def delete_supervision_substitution(request: HttpRequest, id_: int, week: int) -> HttpResponse:
-    """Delete a supervision substitution.
-
-    Redirects back to supervision list on success.
-    """
-    supervision = get_object_or_404(Supervision, pk=id_)
-    wanted_week = supervision.get_calendar_week(week)
-    date = week_weekday_to_date(wanted_week, supervision.break_item.weekday)
-
-    get_supervision_substitution_by_id(request, id_, date).delete()
-
-    messages.success(request, _("The substitution has been deleted."))
-
-    return redirect("supervisions_day_by_date", year=date.year, month=date.month, day=date.day)
+    context = get_substitutions_context_data(request, year, month, day, is_print=True)
+    return render_pdf(request, "chronos/substitutions_print.html", context)
diff --git a/pyproject.toml b/pyproject.toml
index 338e3c2b90c45e6c0cc5a040a4dd9124bda0cfef..fb56e25888a876fd01f48f6ef6e32490d1376bf7 100644
--- a/pyproject.toml
+++ b/pyproject.toml
@@ -1,6 +1,6 @@
 [tool.poetry]
 name = "AlekSIS-App-Chronos"
-version = "4.0.0.dev1"
+version = "4.0.0.dev4"
 packages = [
     { include = "aleksis" }
 ]
@@ -51,9 +51,9 @@ priority = "supplemental"
 [tool.poetry.dependencies]
 python = "^3.10"
 calendarweek = "^0.5.0"
-aleksis-core = "^4.0.0.dev2"
+aleksis-core = "^4.0.0.dev6"
 aleksis-app-resint = "^4.0.0.dev1"
-aleksis-app-cursus = "^0.1.dev0"
+aleksis-app-cursus = "^0.1.0.dev1"
 aleksis-app-kolego = "^0.1.dev0"
diff --git a/aleksis/apps/chronos/util/chronos_helpers.py b/aleksis/apps/chronos/util/chronos_helpers.py
index 1f299424047084ceeec346a22b9e9c1aa00127ed..e5d5fe9c340f4a491679bf69d4d3abb358e2787d 100644
--- a/aleksis/apps/chronos/util/chronos_helpers.py
+++ b/aleksis/apps/chronos/util/chronos_helpers.py
@@ -96,38 +96,44 @@ def get_teachers(user: "User"):
     return teachers
 
 
-def get_classes(user: "User"):
-    """Get the classes whose timetables are allowed to be seen by current user."""
+def get_groups(user: "User"):
+    """Get the groups whose timetables are allowed to be seen by current user."""
     checker = ObjectPermissionChecker(user)
 
-    classes = (
+    groups = (
         Group.objects.for_current_school_term_or_all()
         .annotate(
             lessons_count=Count("lesson_events"),
             child_lessons_count=Count("child_groups__lesson_events"),
         )
         .filter(Q(lessons_count__gt=0) | Q(child_lessons_count__gt=0))
-        .order_by("short_name", "name")
     )
 
+    group_types = get_site_preferences()["chronos__group_types_timetables"]
+
+    if group_types:
+        groups = groups.filter(group_type__in=group_types)
+
+    groups = groups.order_by("short_name", "name")
+
     if not check_global_permission(user, "chronos.view_all_group_timetables"):
-        checker.prefetch_perms(classes)
+        checker.prefetch_perms(groups)
 
         wanted_classes = set()
 
-        for _class in classes:
+        for _class in groups:
             if checker.has_perm("core.view_group_timetable", _class):
                 wanted_classes.add(_class.pk)
 
-        classes = classes.filter(
+        groups = groups.filter(
             Q(pk__in=wanted_classes) | Q(members=user.person) | Q(owners=user.person)
         )
         if user.person.primary_group:
-            classes = classes.filter(Q(pk=user.person.primary_group.pk))
+            groups = groups.filter(Q(pk=user.person.primary_group.pk))
 
-    classes = classes.distinct()
+    groups = groups.distinct()
 
-    return classes
+    return groups
 
 
 def get_rooms(user: "User"):